pub struct AsyncSendmailTransport<E: Executor> { /* private fields */ }Available on crate feature
sendmail-transport and (crate features async-std1 or tokio1) only.Expand description
Asynchronously sends emails using the sendmail command
Implementations
Sourceimpl<E> AsyncSendmailTransport<E>where
E: Executor,
impl<E> AsyncSendmailTransport<E>where
E: Executor,
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new transport with the sendmail command
Note: This uses the sendmail command in the current PATH. To use another command,
use AsyncSendmailTransport::new_with_command.
Sourcepub fn new_with_command<S: Into<OsString>>(command: S) -> Self
pub fn new_with_command<S: Into<OsString>>(command: S) -> Self
Creates a new transport to the given sendmail command