pub struct FileTransport { /* private fields */ }Available on crate feature
file-transport only.Expand description
Writes the content and the envelope information to a file
Implementations
Sourceimpl FileTransport
impl FileTransport
Sourcepub fn new<P: AsRef<Path>>(path: P) -> FileTransport
pub fn new<P: AsRef<Path>>(path: P) -> FileTransport
Creates a new transport to the given directory
Writes the email content in eml format.
Sourcepub fn with_envelope<P: AsRef<Path>>(path: P) -> FileTransport
Available on crate feature file-transport-envelope only.
pub fn with_envelope<P: AsRef<Path>>(path: P) -> FileTransport
file-transport-envelope only.Creates a new transport to the given directory
Writes the email content in eml format and the envelope in json format.